NXSDataWriter Tango Class Attributes

NXSDataWriter Class Attributes
Name | Inherited | Abstract | Attr. type | R/W type | Data type | Level | Description
XMLSettings | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | EXPERT | An XML string with Nexus configuration.
JSONRecord | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | EXPERT | A JSON string with global client data.
FileName | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | OPERATOR | A name of H5 output file with its full path
CurrentFileId | false | false | Scalar | READ | Tango::DEV_LONG | OPERATOR | Current file id
StepsPerFile | false | false | Scalar | READ_WRITE | Tango::DEV_LONG | OPERATOR | Steps per file
CanFail | false | false | Scalar | READ_WRITE | Tango::DEV_BOOLEAN | OPERATOR | Global can fail flag. By default it is False
SkipAcquisition | false | false | Scalar | READ_WRITE | Tango::DEV_BOOLEAN | OPERATOR | Skip acquisition. It is set to default False value after excuting the OpenEntry, Record or CloseEntry
Errors | false | false | Spectrum | READ | Tango::DEV_STRING | OPERATOR | list of errors

There is no dynamic attribute defined.